@@ -7,25 +7,27 @@ from loguru import logger
 
 
 @click.command()
-@click.option('-t',is_flag=True )
+@click.option('-t', help = "firstwaitTime", type = int, default = 15)
 @click.option('-k', required=False, type = int, help='kill all process on device, enter -1 to kill all tasks on all GPUs')
-# @click.argument('file',nargs=-1 ,type=click.File('rb'))
 @click.option('-f', help="the script for assignment", type=click.STRING)
-@click.option('-n', help="task number on each device ", type=int, defaut = 3)
+@click.option('-n', help="task quantitative limitation on each device ", type=int, default = 3)
+@click.option('-d', help="select specific device to run tasks", type=str)
+@click.option('-l', help="safe free memory level to ensure no overflow", type=float, default = 0.9)
 
 
 
 
-def main( t,k,f,n):
+def main( t,k,f,n,d,l):
+
+
     gpugo = GPUgo()
     gpugo.GetGpuInfo()
     GPUs = gpugo.GPUs
-    logger.add("./file.log",format="{time} {message}", filter="", level="INFO") 
 
-    # logger.info(gpugo.GpuProcessInfo())
-    # logger.info(gpugo.Pidmem(8187))
-    
+    if d:
+        GPUs = [gpu for  gpu in GPUs if gpu.GPU_index in d.split(',')]
 
+ 
     if not f:
         gpugo.ShowmyGpuInfo()
     if f:
@@ -34,7 +36,9 @@ def main( t,k,f,n):
             return
 
         assert os.path.isfile(f), "Please enter correct script path!"
-        assign = TaskAssignment(task_path = f,  perdetask = n)
+        logger.add("./file.log",format="{time} {message}", filter="", level="INFO") 
+      
+        assign = TaskAssignment(task_path = f,  perdetask = n, firstwaitTime = t, maxdeiveoccmem = l)
         assign.run()
 
     
